@@ -1,7 +1,3 @@
-#ifndef SQUID_CONFIG_H
-#include "config.h"
-#endif
-
 #ifndef _getnameinfo_h
 #define _getnameinfo_h
 /*
@@ -20,6 +16,5 @@ SQUIDCEXTERN int xgetnameinfo(const struct sockaddr *sa,
                               int flags );
 #define getnameinfo	xgetnameinfo
 
-
 #endif /* HAVE_GETNAMEINFO */
 #endif /* _getnameinfo_h */
